@@ -135,7 +135,7 @@ rrreg <- function(formula, p, p0, p1, q, design, data, start = NULL,
                           se = se,
                           data = df,
                           coef.names = colnames(x),
-                          x = x,
+                          x = x1, #unscaled data
                           y = y,
                           design = design,
                           call = match.call())
